https://gcc.gnu.org/bugzilla/show_bug.cgi?id=61389
--- Comment #1 from Ed Smith-Rowland <3dw4rd at verizon dot net> ---
Here is a shot at the language of variadic macro arguments in macro.c:

Index: macro.c
===================================================================
--- macro.c     (revision 212209)
+++ macro.c     (working copy)
@@ -713,19 +713,19 @@

   if (argc < macro->paramc)
     {
       /* As an extension, a rest argument is allowed to not appear in
         the invocation at all.
         e.g. #define debug(format, args...) something
         debug("string");

-        This is exactly the same as if there had been an empty rest
-        argument - debug("string", ).  */
+        This is exactly the same as if an empty variadic list had been
+        supplied - debug("string", ).  */

       if (argc + 1 == macro->paramc && macro->variadic)
        {
          if (CPP_PEDANTIC (pfile) && ! macro->syshdr)
            cpp_error (pfile, CPP_DL_PEDWARN,
-                      "ISO C99 requires rest arguments to be used");
+                      "ISO C99 requires variadic arguments to be supplied");
          return true;
        }
@@ -713,19 +713,19 @@
   if (argc < macro->paramc)
     {
-      /* As an extension, a rest argument is allowed to not appear in
+      /* As an extension, variadic arguments are allowed to not appear in
         the invocation at all.
         e.g. #define debug(format, args...) something

Reply via email to